MulDataFrame
===========================

.. toctree::
   :maxdepth: 1
   :caption: Constructor:

   muldataframe

.. toctree::
   :maxdepth: 1
   :caption: Attributes:

   index
   columns
   values
   df
   ds
   shape
   primary_index
   primary_columns
   mindex
   mcolumns
   mcols
   pindex
   pcolumns
   pcols

.. toctree::
   :maxdepth: 1
   :caption: Indexing:

   iloc
   loc
   mloc
   nloc

.. toctree::
   :maxdepth: 1
   :caption: Methods:

   __iter__
   copy
   equals
   transpose
   set_index
   reset_index
   query
   iterrows
   sort_values
   drop_duplicates
   call
   groupby
   melt
   insert
   drop

